@@ -12,30 +12,21 @@ where
     T: Store + Sync + ?Sized,
 {
     async fn start(&self, store: &T) -> Result<()>;
-    async fn create(&self, store: &T) -> Result<models::ContainerCreateResponse>;
-    async fn run(&self, store: &T) -> Result<()>;
+    async fn create(&self, store: &T) -> Result<()>;
+    async fn init(&self, store: &T) -> Result<()>;
     async fn stop(&self, store: &T) -> Result<()>;
-    async fn reset(&self, store: &T) -> Result<()>;
-    async fn ping(&self, store: &T) -> Result<()>;
+    async fn destory(&self, store: &T) -> Result<()>;
+    async fn init_db(&self, store: &T) -> Result<()>;
+    async fn check_health(&self, store: &T) -> Result<()>;
+
     async fn wait_ready(&self, store: &T) -> Result<()> {
-        while let Err(e) = self.ping(store).await {
+        while let Err(e) = self.check_health(store).await {
             info!("⏳ Wait for the store to be ready ...");
-            debug!("ping failed: {}", e);
+            debug!("check health failed: {}", e);
             tokio::time::sleep(Duration::SECOND * 2).await;
         }
         Ok(())
     }
-    async fn init(&self, store: &T) -> Result<()> {
-        self.reset(store)
-            .or_else(async move |e| {
-                debug!("reset failed: {}", e);
-                self.run(store).await?;
-                self.wait_ready(store).await?;
-                info!("❇️ Store is ready");
-                Ok(())
-            })
-            .await
-    }
 }
 
 #[async_trait]
@@ -44,11 +35,12 @@ where
     T: Store + Sync + ?Sized,
 {
     async fn start(&self, store: &T) -> Result<()> {
-        info!("🕹️ Starting container '{}' ...", store.name());
+        info!("💫 Starting container '{}' ...", store.name());
         Ok(self.start_container::<String>(&store.name(), None).await?)
     }
-    async fn create(&self, store: &T) -> Result<models::ContainerCreateResponse> {
-        info!("🛠️ Creating container '{}' ...", store.name());
+
+    async fn create(&self, store: &T) -> Result<()> {
+        info!("📦 Creating container '{}' ...", store.name());
         let config = container::Config {
             image: Some(store.image()),
             env: Some(store.envs()),
@@ -76,17 +68,35 @@ where
             ..Default::default()
         };
 
-        Ok(self
-            .create_container(Some(container::CreateContainerOptions { name: store.name() }), config)
-            .await?)
+        self.create_container(Some(container::CreateContainerOptions { name: store.name() }), config)
+            .await?;
+        Ok(())
     }
-    async fn run(&self, store: &T) -> Result<()> {
-        if self.inspect_image(&store.image()).await.is_err() {
-            pull(self, &store.image()).await?
+
+    async fn init(&self, store: &T) -> Result<()> {
+        match self.check_health(store).await {
+            Ok(_) => {
+                info!("🔰 Store is already running");
+                self.init_db(store).await?;
+            }
+            _ => {
+                self.inspect_image(&store.image())
+                    .map_ok(|_| ())
+                    .or_else(async move |_| {
+                        info!("🚚 Pulling image '{}' ...", store.image());
+                        pull(self, &store.image()).await
+                    })
+                    .and_then(|_| self.create(store))
+                    .and_then(|_| self.start(store))
+                    .and_then(|_| self.wait_ready(store))
+                    .and_then(|_| self.init_db(store))
+                    .await?;
+                info!("🔰 Store is ready");
+            }
         };
-        self.create(store).await?;
-        self.start(store).await
+        Ok(())
     }
+
     async fn stop(&self, store: &T) -> Result<()> {
         self.stop_container(&store.name(), None).await.or_else(|e| match e {
             DockerResponseNotFoundError { .. } => {
@@ -96,11 +106,18 @@ where
             _ => Err(e.into()),
         })
     }
-    async fn reset(&self, store: &T) -> Result<()> {
-        info!("♻️ Reseting store ...");
-        exec(self, &store.name(), store.reset_cmd()).await
+
+    async fn destory(&self, store: &T) -> Result<()> {
+        info!("🔥 Destroy database ...");
+        exec(self, &store.name(), store.drop_cmd()).await
     }
-    async fn ping(&self, store: &T) -> Result<()> {
+
+    async fn init_db(&self, store: &T) -> Result<()> {
+        info!("🌀 Initializing database ...");
+        exec(self, &store.name(), store.init_db_cmd()).await
+    }
+
+    async fn check_health(&self, store: &T) -> Result<()> {
         exec(self, &store.name(), store.ping_cmd()).await
     }
 }
@@ -134,7 +151,6 @@ async fn exec(docker: &Docker, container: &str, cmd: Vec<String>) -> Result<()>
 }
 
 async fn pull(docker: &Docker, image: &str) -> Result<()> {
-    info!("📦 Pulling image '{}' ...", image);
     docker
         .create_image(
             Some(image::CreateImageOptions { from_image: image, ..Default::default() }),
