@@ -29,7 +29,7 @@ async fn main() {
                 std::process::exit(0);
             }
         }
-        error!("{}", e);
+        error!("❗ {}", e.to_string().trim());
         std::process::exit(1)
     }
 }
@@ -52,8 +52,26 @@ async fn try_main() -> Result<()> {
                         docker.init(&Redis { port, password, database }).await?;
                     }
                 }
+                info!("✨ Initialized playground '{name}'");
+            }
+        }
+        App::Clear { backends } => {
+            let backends: BackendMap = backends.try_into()?;
+            for (name, backend) in backends.into_iter() {
+                info!("🧹 Cleaning up playground '{name}' ...");
+                match backend {
+                    Backend::Postgres { port, user, password, database, .. } => {
+                        docker.destory(&Postgres { port, user, password, database }).await?;
+                    }
+                    Backend::Mysql { port, user, password, database, .. } => {
+                        docker.destory(&Mysql { port, user, password, database }).await?;
+                    }
+                    Backend::Redis { port, password, database, .. } => {
+                        docker.destory(&Redis { port, password, database }).await?;
+                    }
+                }
+                info!("✨ Cleaned up playground '{name}'");
             }
-            info!("✨ All playgrounds initialized successfully!");
         }
         App::Stop { backends } => {
             let backends: BackendMap = backends.try_into()?;
@@ -70,8 +88,8 @@ async fn try_main() -> Result<()> {
                         docker.stop(&Redis { port, password, database }).await?;
                     }
                 }
+                info!("🛑 Stopped playground '{name}'");
             }
-            info!("🛑 All playgrounds stopped");
         }
         App::Completion { shell } => {
             let app = &mut App::into_app();
