@@ -8,8 +8,9 @@ pub trait Store {
     fn name(&self) -> String;
     fn image(&self) -> String;
     fn port_map(&self) -> Vec<PortMap>;
-    fn reset_cmd(&self) -> Vec<String>;
     fn ping_cmd(&self) -> Vec<String>;
+    fn drop_cmd(&self) -> Vec<String>;
+    fn init_db_cmd(&self) -> Vec<String>;
 
     fn envs(&self) -> Vec<String> {
         vec![]
